@@ -1,6 +1,5 @@
 from .b_colors import BColors
 from .generate_session import GenerateSession
-from .get_active_voice_chat import GetActiveVoiceChat
 from .get_port_server import GetPortServer
 from .get_user_id import GetUserId
 from .run_js import RunJS
@@ -11,7 +10,6 @@ class Core(
     GenerateSession,
     GetUserId,
     GetPortServer,
-    GetActiveVoiceChat,
     SpawnProcess,
     BColors,
     RunJS,
